# SKM-TEA Model Zoo and Baselines

## Introduction
This file is a running document of baselines and state-of-the-art models for the SKM-TEA v1 dataset.


## Reconstruction Baselines

| Name                       | Input        | Train Acc.   | Description                            | Download                                                                                                                                                                                                                                                                                                                                                                        |
|:---------------------------|:-------------|:-------------|:---------------------------------------|:--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| Unrolled E1 (6x)           | E1           | 6x           | 8 resblocks,<br>256 channels each      | [🤗](https://huggingface.co/arjundd/skm-tea-models/tree/main/neurips2021/recon-models/6x/Unrolled_E1) \| [cfg](https://huggingface.co/arjundd/skm-tea-models/raw/main/neurips2021/recon-models/6x/Unrolled_E1/config.yaml) \| [model](https://huggingface.co/arjundd/skm-tea-models/resolve/main/neurips2021/recon-models/6x/Unrolled_E1/model.ckpt)                            |
| Unrolled E2 (6x)           | E2           | 6x           | 8 resblocks,<br>256 channels each      | [🤗](https://huggingface.co/arjundd/skm-tea-models/tree/main/neurips2021/recon-models/6x/Unrolled_E2) \| [cfg](https://huggingface.co/arjundd/skm-tea-models/raw/main/neurips2021/recon-models/6x/Unrolled_E2/config.yaml) \| [model](https://huggingface.co/arjundd/skm-tea-models/resolve/main/neurips2021/recon-models/6x/Unrolled_E2/model.ckpt)                            |
| Unrolled E1+E2 (6x)        | E1+E2        | 6x           | 8 resblocks,<br>256 channels each      | [🤗](https://huggingface.co/arjundd/skm-tea-models/tree/main/neurips2021/recon-models/6x/Unrolled_E1+E2) \| [cfg](https://huggingface.co/arjundd/skm-tea-models/raw/main/neurips2021/recon-models/6x/Unrolled_E1+E2/config.yaml) \| [model](https://huggingface.co/arjundd/skm-tea-models/resolve/main/neurips2021/recon-models/6x/Unrolled_E1+E2/model.ckpt)                   |
| Unrolled E1$\oplus$E2 (6x) | E1$\oplus$E2 | 6x           | 8 resblocks,<br>256 channels each      | [🤗](https://huggingface.co/arjundd/skm-tea-models/tree/main/neurips2021/recon-models/6x/Unrolled_E1-oplus-E2) \| [cfg](https://huggingface.co/arjundd/skm-tea-models/raw/main/neurips2021/recon-models/6x/Unrolled_E1-oplus-E2/config.yaml) \| [model](https://huggingface.co/arjundd/skm-tea-models/resolve/main/neurips2021/recon-models/6x/Unrolled_E1-oplus-E2/model.ckpt) |
| U-Net E1 (6x)              | E1           | 6x           | 4 pooling, 32^p, leaky-relu activation | [🤗](https://huggingface.co/arjundd/skm-tea-models/tree/main/neurips2021/recon-models/6x/U-Net_E1) \| [cfg](https://huggingface.co/arjundd/skm-tea-models/raw/main/neurips2021/recon-models/6x/U-Net_E1/config.yaml) \| [model](https://huggingface.co/arjundd/skm-tea-models/resolve/main/neurips2021/recon-models/6x/U-Net_E1/model.ckpt)                                     |
| U-Net E2 (6x)              | E2           | 6x           | 4 pooling, 32^p, leaky-relu activation | [🤗](https://huggingface.co/arjundd/skm-tea-models/tree/main/neurips2021/recon-models/6x/U-Net_E2) \| [cfg](https://huggingface.co/arjundd/skm-tea-models/raw/main/neurips2021/recon-models/6x/U-Net_E2/config.yaml) \| [model](https://huggingface.co/arjundd/skm-tea-models/resolve/main/neurips2021/recon-models/6x/U-Net_E2/model.ckpt)                                     |
| U-Net E1+E2 (6x)           | E1+E2        | 6x           | 4 pooling, 32^p, leaky-relu activation | [🤗](https://huggingface.co/arjundd/skm-tea-models/tree/main/neurips2021/recon-models/6x/U-Net_E1+E2) \| [cfg](https://huggingface.co/arjundd/skm-tea-models/raw/main/neurips2021/recon-models/6x/U-Net_E1+E2/config.yaml) \| [model](https://huggingface.co/arjundd/skm-tea-models/resolve/main/neurips2021/recon-models/6x/U-Net_E1+E2/model.ckpt)                            |
| U-Net E1$\oplus$E2 (6x)    | E1$\oplus$E2 | 6x           | 4 pooling, 32^p, leaky-relu activation | [🤗](https://huggingface.co/arjundd/skm-tea-models/tree/main/neurips2021/recon-models/6x/U-Net_E1-oplus-E2) \| [cfg](https://huggingface.co/arjundd/skm-tea-models/raw/main/neurips2021/recon-models/6x/U-Net_E1-oplus-E2/config.yaml) \| [model](https://huggingface.co/arjundd/skm-tea-models/resolve/main/neurips2021/recon-models/6x/U-Net_E1-oplus-E2/model.ckpt)          |
| Unrolled E1 (8x)           | E1           | 8x           | 8 resblocks,<br>256 channels each      | [🤗](https://huggingface.co/arjundd/skm-tea-models/tree/main/neurips2021/recon-models/8x/Unrolled_E1) \| [cfg](https://huggingface.co/arjundd/skm-tea-models/raw/main/neurips2021/recon-models/8x/Unrolled_E1/config.yaml) \| [model](https://huggingface.co/arjundd/skm-tea-models/resolve/main/neurips2021/recon-models/8x/Unrolled_E1/model.ckpt)                            |
| Unrolled E2 (8x)           | E2           | 8x           | 8 resblocks,<br>256 channels each      | [🤗](https://huggingface.co/arjundd/skm-tea-models/tree/main/neurips2021/recon-models/8x/Unrolled_E2) \| [cfg](https://huggingface.co/arjundd/skm-tea-models/raw/main/neurips2021/recon-models/8x/Unrolled_E2/config.yaml) \| [model](https://huggingface.co/arjundd/skm-tea-models/resolve/main/neurips2021/recon-models/8x/Unrolled_E2/model.ckpt)                            |
| Unrolled E1+E2 (8x)        | E1+E2        | 8x           | 8 resblocks,<br>256 channels each      | [🤗](https://huggingface.co/arjundd/skm-tea-models/tree/main/neurips2021/recon-models/8x/Unrolled_E1+E2) \| [cfg](https://huggingface.co/arjundd/skm-tea-models/raw/main/neurips2021/recon-models/8x/Unrolled_E1+E2/config.yaml) \| [model](https://huggingface.co/arjundd/skm-tea-models/resolve/main/neurips2021/recon-models/8x/Unrolled_E1+E2/model.ckpt)                   |
| Unrolled E1$\oplus$E2 (8x) | E1$\oplus$E2 | 8x           | 8 resblocks,<br>256 channels each      | [🤗](https://huggingface.co/arjundd/skm-tea-models/tree/main/neurips2021/recon-models/8x/Unrolled_E1-oplus-E2) \| [cfg](https://huggingface.co/arjundd/skm-tea-models/raw/main/neurips2021/recon-models/8x/Unrolled_E1-oplus-E2/config.yaml) \| [model](https://huggingface.co/arjundd/skm-tea-models/resolve/main/neurips2021/recon-models/8x/Unrolled_E1-oplus-E2/model.ckpt) |
| U-Net E1 (8x)              | E1           | 8x           | 4 pooling, 32^p, leaky-relu activation | [🤗](https://huggingface.co/arjundd/skm-tea-models/tree/main/neurips2021/recon-models/8x/U-Net_E1) \| [cfg](https://huggingface.co/arjundd/skm-tea-models/raw/main/neurips2021/recon-models/8x/U-Net_E1/config.yaml) \| [model](https://huggingface.co/arjundd/skm-tea-models/resolve/main/neurips2021/recon-models/8x/U-Net_E1/model.ckpt)                                     |
| U-Net E2 (8x)              | E2           | 8x           | 4 pooling, 32^p, leaky-relu activation | [🤗](https://huggingface.co/arjundd/skm-tea-models/tree/main/neurips2021/recon-models/8x/U-Net_E2) \| [cfg](https://huggingface.co/arjundd/skm-tea-models/raw/main/neurips2021/recon-models/8x/U-Net_E2/config.yaml) \| [model](https://huggingface.co/arjundd/skm-tea-models/resolve/main/neurips2021/recon-models/8x/U-Net_E2/model.ckpt)                                     |
| U-Net E1+E2 (8x)           | E1+E2        | 8x           | 4 pooling, 32^p, leaky-relu activation | [🤗](https://huggingface.co/arjundd/skm-tea-models/tree/main/neurips2021/recon-models/8x/U-Net_E1+E2) \| [cfg](https://huggingface.co/arjundd/skm-tea-models/raw/main/neurips2021/recon-models/8x/U-Net_E1+E2/config.yaml) \| [model](https://huggingface.co/arjundd/skm-tea-models/resolve/main/neurips2021/recon-models/8x/U-Net_E1+E2/model.ckpt)                            |
| U-Net E1$\oplus$E2 (8x)    | E1$\oplus$E2 | 8x           | 4 pooling, 32^p, leaky-relu activation | [🤗](https://huggingface.co/arjundd/skm-tea-models/tree/main/neurips2021/recon-models/8x/U-Net_E1-oplus-E2) \| [cfg](https://huggingface.co/arjundd/skm-tea-models/raw/main/neurips2021/recon-models/8x/U-Net_E1-oplus-E2/config.yaml) \| [model](https://huggingface.co/arjundd/skm-tea-models/resolve/main/neurips2021/recon-models/8x/U-Net_E1-oplus-E2/model.ckpt)          |


## Segmentation Baselines
| Name               | Input        | Description                     | Download                                                                                                                                                                                                                                                                                                                                                                           |
|:-------------------|:-------------|:--------------------------------|:-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| V-Net E1           | E1           | Monai v0.5.3                    | [🤗](https://huggingface.co/arjundd/skm-tea-models/tree/main/neurips2021/segmentation-models/V-Net_E1) \| [cfg](https://huggingface.co/arjundd/skm-tea-models/raw/main/neurips2021/segmentation-models/V-Net_E1/config.yaml) \| [model](https://huggingface.co/arjundd/skm-tea-models/resolve/main/neurips2021/segmentation-models/V-Net_E1/model.ckpt)                            |
| V-Net E2           | E2           | Monai v0.5.3                    | [🤗](https://huggingface.co/arjundd/skm-tea-models/tree/main/neurips2021/segmentation-models/V-Net_E2) \| [cfg](https://huggingface.co/arjundd/skm-tea-models/raw/main/neurips2021/segmentation-models/V-Net_E2/config.yaml) \| [model](https://huggingface.co/arjundd/skm-tea-models/resolve/main/neurips2021/segmentation-models/V-Net_E2/model.ckpt)                            |
| V-Net E1$\oplus$E2 | E1$\oplus$E2 | Monai v0.5.3                    | [🤗](https://huggingface.co/arjundd/skm-tea-models/tree/main/neurips2021/segmentation-models/V-Net_E1-oplus-E2) \| [cfg](https://huggingface.co/arjundd/skm-tea-models/raw/main/neurips2021/segmentation-models/V-Net_E1-oplus-E2/config.yaml) \| [model](https://huggingface.co/arjundd/skm-tea-models/resolve/main/neurips2021/segmentation-models/V-Net_E1-oplus-E2/model.ckpt) |
| V-Net RSS          | RSS          | Monai v0.5.3                    | [🤗](https://huggingface.co/arjundd/skm-tea-models/tree/main/neurips2021/segmentation-models/V-Net_RSS) \| [cfg](https://huggingface.co/arjundd/skm-tea-models/raw/main/neurips2021/segmentation-models/V-Net_RSS/config.yaml) \| [model](https://huggingface.co/arjundd/skm-tea-models/resolve/main/neurips2021/segmentation-models/V-Net_RSS/model.ckpt)                         |
| U-Net E1           | E1           | 5 pooling layers, 32^p channels | [🤗](https://huggingface.co/arjundd/skm-tea-models/tree/main/neurips2021/segmentation-models/U-Net_E1) \| [cfg](https://huggingface.co/arjundd/skm-tea-models/raw/main/neurips2021/segmentation-models/U-Net_E1/config.yaml) \| [model](https://huggingface.co/arjundd/skm-tea-models/resolve/main/neurips2021/segmentation-models/U-Net_E1/model.ckpt)                            |
| U-Net E2           | E2           | 5 pooling layers, 32^p channels | [🤗](https://huggingface.co/arjundd/skm-tea-models/tree/main/neurips2021/segmentation-models/U-Net_E2) \| [cfg](https://huggingface.co/arjundd/skm-tea-models/raw/main/neurips2021/segmentation-models/U-Net_E2/config.yaml) \| [model](https://huggingface.co/arjundd/skm-tea-models/resolve/main/neurips2021/segmentation-models/U-Net_E2/model.ckpt)                            |
| U-Net E1$\oplus$E2 | E1$\oplus$E2 | 5 pooling layers, 32^p channels | [🤗](https://huggingface.co/arjundd/skm-tea-models/tree/main/neurips2021/segmentation-models/U-Net_E1-oplus-E2) \| [cfg](https://huggingface.co/arjundd/skm-tea-models/raw/main/neurips2021/segmentation-models/U-Net_E1-oplus-E2/config.yaml) \| [model](https://huggingface.co/arjundd/skm-tea-models/resolve/main/neurips2021/segmentation-models/U-Net_E1-oplus-E2/model.ckpt) |
| U-Net RSS          | RSS          | 5 pooling layers, 32^p channels | [🤗](https://huggingface.co/arjundd/skm-tea-models/tree/main/neurips2021/segmentation-models/U-Net_RSS) \| [cfg](https://huggingface.co/arjundd/skm-tea-models/raw/main/neurips2021/segmentation-models/U-Net_RSS/config.yaml) \| [model](https://huggingface.co/arjundd/skm-tea-models/resolve/main/neurips2021/segmentation-models/U-Net_RSS/model.ckpt)                         |